==> v1.12.6.zip: wcs/wcs/qommon/static/js/wcs.listing.js <==
function prepare_page_links() {
  $('#page-links a').click(function() {
    $('form#listing-settings input[name="offset"]').val($(this).data('offset'));
    refresh_table();
    return false;
  });
}

function prepare_row_links() {
  $('#listing tbody tr a').on('click', function(event) {
    event.stopPropagation();
  });
  $('#listing tbody tr').on('click', function() {
    var data_link = $(this).data('link');
    if (data_link) {
      window.location = window.location.pathname + data_link;
      return false;
    }
  });
}

function prepare_column_headers() {
  if ($('input[name="order_by"]').length == 0) {
    /* if we don't have an order_by field, that means we do not support server
     * side sorting; in that case, and if there's no pagination, we fallback to
     * using javascript tablesorter */
    if ($('#page-links').length == 0) { /* no pagination */
      $('table.sortable').tablesorter();
    }
    return;
  }
  var current_key = $('input[name="order_by"]').val();
  var sort_key = null;
  var reversed = true;
  if (current_key[0] === '-') {
    sort_key = current_key.substring(1);
    reversed = true;
  } else {
    sort_key = current_key;
    reversed = false;
  }
  if (reversed) {
    $('#listing thead th[data-field-sort-key="' + sort_key + '"]').addClass('headerSortUp');
  } else {
    $('#listing thead th[data-field-sort-key="' + sort_key + '"]').addClass('headerSortDown');
  }
  $('#listing thead th[data-field-sort-key]').addClass('header').click(function() {
    new_key = $(this).data('field-sort-key');
    if (current_key === sort_key) {
      if (reversed === false) {
        new_key = '-' + new_key
      }
    }
    $('input[name="order_by"]').val(new_key);
    refresh_table();
  });
}

function refresh_table() {
  var listing_settings = $('form#listing-settings').serialize();
  /* makes sure it doesn't start with a double slash */
  var pathname = window.location.pathname.replace(/^\/+/, '/');

  $.ajax({
    url: pathname + '?ajax=true&' + listing_settings,
    beforeSend: function() { $('#main-content h2, #listing').addClass('activity'); },
    complete: function() { $('#main-content h2, #listing').removeClass('activity'); },
    success: function(html) {
      $('#page-links').remove();
      $('table#listing').replaceWith(html);
      prepare_page_links();
      prepare_row_links();
      prepare_column_headers();
      $('a[data-base-href]').each(function(idx, elem) {
        $(elem).attr('href', $(elem).data('base-href') + '?' + listing_settings);
      });
      if (window.history) {
        window.history.replaceState(null, null, pathname + '?' + listing_settings);
      }
    }
  });
}

$(function() {
  /* column settings */
  $('#columns-settings').click(function() {
    var dialog = $('<form>');
    $('#columns-filter').clone().appendTo(dialog);
    $(dialog).find('input').each(function(idx, elem) {
      $(this).attr('id', 'dlg-' + $(this).attr('id'));
    });
    $(dialog).find('label').each(function(idx, elem) {
      $(this).attr('for', 'dlg-' + $(this).attr('for'));
    });
    $(dialog).dialog({
            modal: true,
            resizable: false,
            title: $('#columns-settings').text(),
            width: '30em'});
    $(dialog).dialog('option', 'buttons', [
            {text: $('form#listing-settings button.refresh').text(),
             click: function() {
                $(this).find('input[type="checkbox"]').each(function(idx, elem) {
                $('form#listing-settings input[name="' + $(elem).attr('name') + '"]').prop('checked',
                        $(elem).prop('checked'));
                });
                $(this).dialog('close');
                $('form#listing-settings').submit();
              }
            }]);
    return false;
  });
  /* possibility to toggle the sidebar */
  $('#main-content').after($('<span id="sidebar-toggle">&#8286;</span>'));
  $('#sidebar-toggle').click(function() {
    if ($('#sidebar').css('display') === 'none') {
      $('#main-content').animate({width: '70%'}, 400,
              function() {$('#sidebar').show()});
    } else {
      $('#sidebar').hide();
      $('#main-content').animate({width: '95%'});
    }
  });
  /* automatically refresh on status change */
  $('form#listing-settings select[name="filter"]').change(function() {
    $('form#listing-settings').submit();
  });
  /* partial table refresh */
  $('form#listing-settings').submit(function(event) {
    event.preventDefault();
    refresh_table();
    return false;
  });
  prepare_page_links();
  prepare_row_links();
  prepare_column_headers();
});

==> v1.12.9.zip: wcs/wcs/qommon/static/js/wcs.listing.js <==
function prepare_page_links() {
  $('#page-links a').click(function() {
    $('form#listing-settings input[name="offset"]').val($(this).data('offset'));
    refresh_table();
    return false;
  });
}

function prepare_row_links() {
  $('#listing tbody tr a').on('click', function(event) {
    event.stopPropagation();
  });
  $('#listing tbody tr').on('click', function() {
    var data_link = $(this).data('link');
    if (data_link) {
      window.location = window.location.pathname + data_link;
      return false;
    }
  });
}

function prepare_column_headers() {
  if ($('input[name="order_by"]').length == 0) {
    /* if we don't have an order_by field, that means we do not support server
     * side sorting; in that case, and if there's no pagination, we fallback to
     * using javascript tablesorter */
    if ($('#page-links').length == 0 && $('table.sortable').length) {
      /* no pagination and a table */
      $('table.sortable').tablesorter();
    }
    return;
  }
  var current_key = $('input[name="order_by"]').val();
  var sort_key = null;
  var reversed = true;
  if (current_key[0] === '-') {
    sort_key = current_key.substring(1);
    reversed = true;
  } else {
    sort_key = current_key;
    reversed = false;
  }
  if (reversed) {
    $('#listing thead th[data-field-sort-key="' + sort_key + '"]').addClass('headerSortUp');
  } else {
    $('#listing thead th[data-field-sort-key="' + sort_key + '"]').addClass('headerSortDown');
  }
  $('#listing thead th[data-field-sort-key]').addClass('header').click(function() {
    new_key = $(this).data('field-sort-key');
    if (current_key === sort_key) {
      if (reversed === false) {
        new_key = '-' + new_key
      }
    }
    $('input[name="order_by"]').val(new_key);
    refresh_table();
  });
}

function refresh_table() {
  var listing_settings = $('form#listing-settings').serialize();
  /* makes sure it doesn't start with a double slash */
  var pathname = window.location.pathname.replace(/^\/+/, '/');

  $.ajax({
    url: pathname + '?ajax=true&' + listing_settings,
    beforeSend: function() { $('#breadcrumb, #listing').addClass('activity'); },
    complete: function() { $('#breadcrumb, #listing').removeClass('activity'); },
    success: function(html) {
      $('#page-links').remove();
      $('#listing').replaceWith(html);
      prepare_page_links();
      prepare_row_links();
      prepare_column_headers();
      $('a[data-base-href]').each(function(idx, elem) {
        $(elem).attr('href', $(elem).data('base-href') + '?' + listing_settings);
      });
      if (window.history) {
        window.history.replaceState(null, null, pathname + '?' + listing_settings);
      }
      /* makes sure the activity class is well removed */
      $('#breadcrumb, #listing').removeClass('activity');
    }
  });
}

$(function() {
  /* column settings */
  $('#columns-settings').click(function() {
    var dialog = $('<form>');
    $('#columns-filter').clone().appendTo(dialog);
    $(dialog).find('input').each(function(idx, elem) {
      $(this).attr('id', 'dlg-' + $(this).attr('id'));
    });
    $(dialog).find('label').each(function(idx, elem) {
      $(this).attr('for', 'dlg-' + $(this).attr('for'));
    });
    $(dialog).dialog({
            modal: true,
            resizable: false,
            title: $('#columns-settings').text(),
            width: '30em'});
    $(dialog).dialog('option', 'buttons', [
            {text: $('form#listing-settings button.refresh').text(),
             click: function() {
                $(this).find('input[type="checkbox"]').each(function(idx, elem) {
                $('form#listing-settings input[name="' + $(elem).attr('name') + '"]').prop('checked',
                        $(elem).prop('checked'));
                });
                $(this).dialog('close');
                $('form#listing-settings').submit();
              }
            }]);
    return false;
  });
  /* possibility to toggle the sidebar */
  $('#main-content').after($('<span id="sidebar-toggle">&#8286;</span>'));
  $('#sidebar-toggle').click(function() {
    if ($('#sidebar').css('display') === 'none') {
      $('#main-content').animate({width: '70%'}, 400,
              function() {$('#sidebar').show()});
    } else {
      $('#sidebar').hide();
      $('#main-content').animate({width: '95%'});
    }
  });
  /* automatically refresh on status change */
  $('form#listing-settings select[name="filter"]').change(function() {
    $('form#listing-settings').submit();
  });
  /* partial table refresh */
  $('form#listing-settings').submit(function(event) {
    event.preventDefault();
    refresh_table();
    return false;
  });
  prepare_page_links();
  prepare_row_links();
  prepare_column_headers();
});
